# ZeusAI.Py
The python package to wrap the various APIs associated with ZeusAI.

## Usage for Non-Contributors
See the Readthedocs page (TODO) for usage documentation.

## Documentation
To view all of the available documentation for this project, please see the [Documents Index](INDEX.md)
This includes information on getting started, the development environment, and more.

## Version Numbers
ZeusAI.Py is updated at the same time as the ZeusAI server. The first 3 sections of the ZeusAI.Py version number will be the 
associated version number for ZeusAI, with the 4th section being the ZeusAI.Py revision number, which is only updated for bugs.
(i.e. if ZeusAI is on 1.2.3, ZeusAI.Py will be on 1.2.3.x).

If the first three sections of the ZeusAI.Py version number match your ZeusAI version number, they should be compatable.
